Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(349)

Unified Diff: chrome/browser/sync/glue/password_model_associator.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/password_model_associator.h
diff --git a/chrome/browser/sync/glue/password_model_associator.h b/chrome/browser/sync/glue/password_model_associator.h
index 440e846d1e5b8bcb544ecc1f9175441505542010..5c995f4a8a42d361ed7a9938f8f3b397d621ec85 100644
--- a/chrome/browser/sync/glue/password_model_associator.h
+++ b/chrome/browser/sync/glue/password_model_associator.h
@@ -28,7 +28,7 @@ struct PasswordForm;
}
}
-namespace csync {
+namespace syncer {
class WriteNode;
class WriteTransaction;
}
@@ -56,13 +56,13 @@ class PasswordModelAssociator
// PerDataTypeAssociatorInterface implementation.
//
// Iterates through the sync model looking for matched pairs of items.
- virtual csync::SyncError AssociateModels() OVERRIDE;
+ virtual syncer::SyncError AssociateModels() OVERRIDE;
// Delete all password nodes.
- bool DeleteAllNodes(csync::WriteTransaction* trans);
+ bool DeleteAllNodes(syncer::WriteTransaction* trans);
// Clears all associations.
- virtual csync::SyncError DisassociateModels() OVERRIDE;
+ virtual syncer::SyncError DisassociateModels() OVERRIDE;
// The has_nodes out param is true if the sync model has nodes other
// than the permanent tagged nodes.
@@ -79,9 +79,9 @@ class PasswordModelAssociator
// Not implemented.
virtual bool InitSyncNodeFromChromeId(const std::string& node_id,
- csync::BaseNode* sync_node) OVERRIDE;
+ syncer::BaseNode* sync_node) OVERRIDE;
- // Returns the sync id for the given password name, or csync::kInvalidId
+ // Returns the sync id for the given password name, or syncer::kInvalidId
// if the password name is not associated to any sync id.
virtual int64 GetSyncIdFromChromeId(const std::string& node_id) OVERRIDE;
@@ -95,7 +95,7 @@ class PasswordModelAssociator
// |sync_id| with that node's id.
virtual bool GetSyncIdForTaggedNode(const std::string& tag, int64* sync_id);
- csync::SyncError WriteToPasswordStore(const PasswordVector* new_passwords,
+ syncer::SyncError WriteToPasswordStore(const PasswordVector* new_passwords,
const PasswordVector* updated_passwords,
const PasswordVector* deleted_passwords);
@@ -114,7 +114,7 @@ class PasswordModelAssociator
const webkit::forms::PasswordForm& password_form,
webkit::forms::PasswordForm* new_password);
static void WriteToSyncNode(const webkit::forms::PasswordForm& password_form,
- csync::WriteNode* node);
+ syncer::WriteNode* node);
// Called at various points in model association to determine if the
// user requested an abort.
« no previous file with comments | « chrome/browser/sync/glue/password_data_type_controller.cc ('k') | chrome/browser/sync/glue/password_model_associator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698